@@ -8,8 +8,10 @@ from tg_utils.health_check.base_checks import HealthCheckSettingsMixin
 
 
 CACHE_KEY = "CELERY_BEAT_HEALTH_CHECK_TIME_STAMP"
-TIMEOUT = getattr(settings, 'HEALTH_CHECK', {}).get('CELERY_BEAT_CHECK_INTERVAL', 60)
-DELAY_THRESHOLD = getattr(settings, 'HEALTH_CHECK', {}).get('CELERY_BEAT_DELAY_THRESHOLD', 10)
+TIMEOUT = getattr(settings, "HEALTH_CHECK", {}).get("CELERY_BEAT_CHECK_INTERVAL", 60)
+DELAY_THRESHOLD = getattr(settings, "HEALTH_CHECK", {}).get(
+    "CELERY_BEAT_DELAY_THRESHOLD", 10
+)
 
 
 class CeleryBeatHealthCheck(BaseHealthCheckBackend, HealthCheckSettingsMixin):
@@ -18,6 +20,8 @@ class CeleryBeatHealthCheck(BaseHealthCheckBackend, HealthCheckSettingsMixin):
         if last_beat_time is None:
             self.add_error(ServiceUnavailable("Celery beat is not scheduling tasks"))
         elif (datetime.now() - last_beat_time).seconds > DELAY_THRESHOLD:
-            self.add_error(ServiceUnavailable("Celery beat tasks are delayed, last ran at {last_beat_time}.".format(
-                last_beat_time=last_beat_time,
-            )))
+            self.add_error(
+                ServiceUnavailable(
+                    f"Celery beat tasks are delayed, last ran at {last_beat_time}."
+                )
+            )
