@@ -4,8 +4,10 @@ from health_check.plugins import plugin_dir
 
 
 class HealthCheckConfig(AppConfig):
-    name = 'tg_utils.health_check.checks.elvis'
+    name = "tg_utils.health_check.checks.elvis"
 
     def ready(self):
+        # pylint: disable=import-outside-toplevel
         from .backends import ElvisProxyHealthCheck
+
         plugin_dir.register(ElvisProxyHealthCheck)
